# VL Anwendungsorientierte Analyseverfahren, Institut für Publizistik, Uni Mainz
# 2024-07-03

## Pakete und Daten laden

library(marginaleffects)
library(report)
library(tidyverse)
theme_set(theme_minimal())

vb17 <- haven::read_sav("data/Voegele_Bachl_2017.sav") |>
  mutate(geschlecht_w = ifelse(Geschlecht == 1, 1, 0)) |>
  haven::zap_labels()

vb17

## Deskriptivstatistik

vb17 |>
  select(gesamt) |>
  report::report_table()

vb17 |>
  ggplot(aes(x = gesamt)) +
  geom_histogram()

## Interaktion mit kategorieller Moderatorvariable

lm(gesamt ~ schwab + geschlecht_w, data = vb17) |>
  report::report_table()

m1_geschlecht <- lm(gesamt ~ schwab + geschlecht_w + schwab:geschlecht_w, data = vb17)
report::report_table(m1_geschlecht)

marginaleffects::avg_slopes(m1_geschlecht) |>
  as_tibble()

marginaleffects::avg_slopes(m1_geschlecht, variable = "schwab", by = "geschlecht_w") |>
  as_tibble()

preds_schwab_geschlecht <- marginaleffects::avg_predictions(m1_geschlecht, variables = c("schwab", "geschlecht_w")) |>
  as_tibble()
preds_schwab_geschlecht

preds_schwab_geschlecht |>
  mutate(schwab = factor(schwab), geschlecht_w = factor(geschlecht_w)) |>
  ggplot(aes(
    x = schwab, y = estimate, group = geschlecht_w,
    color = geschlecht_w, ymin = conf.low, ymax = conf.high
  )) +
  geom_pointrange(position = position_dodge(.5)) +
  scale_x_discrete(labels = c("Hochdeutsch", "Dialekt")) +
  scale_color_discrete(labels = c("männlich", "weiblich")) +
  labs(
    y = "Gesamtbewertung (vorhergesagt)",
    x = "Versuchsbedingung",
    color = "Geschlecht der ProbandInnen"
  )

## Interaktion mit metrischer Moderatorvariable

m2_atol <- lm(gesamt ~ schwab * atol, data = vb17)
report::report_table(m2_atol)

marginaleffects::avg_slopes(m2_atol) |>
  as_tibble()

lm(gesamt ~ schwab * I(atol - 1), data = vb17) |> # atol = 1
  report_table()

lm(gesamt ~ schwab * I(atol - 5), data = vb17) |> # atol = 5
  report_table()

marginaleffects::plot_slopes(m2_atol, variables = "schwab", condition = "atol") +
  labs(x = "ATOL Score", y = "Effekt von Dialekt auf Bewertung") +
  geom_hline(yintercept = 0, linetype = "dashed")

preds_schwab_atol <- marginaleffects::avg_predictions(m2_atol, variables = list("schwab" = 0:1, "atol" = c(1, 3, 5))) |>
  as_tibble()
preds_schwab_atol

preds_schwab_atol |>
  mutate(atol = factor(atol, labels = c("niedrig (1)", "mittel (3)", "hoch (5)"))) |>
  ggplot(aes(
    x = factor(schwab), y = estimate, ymin = conf.low, ymax = conf.high,
    group = atol, color = atol,
  )) +
  geom_pointrange(position = position_dodge(.33)) +
  geom_line(position = position_dodge(.33)) +
  scale_x_discrete(labels = c("Hochdeutsch", "Dialekt")) +
  labs(y = "Gesamtbewertung (vorhergesagt)", x = "Dialekt", color = "ATOL Score")

